@@ -37,4 +37,10 @@ sub compute_scan {
 	
 }
 
+sub get_scans {
+	my $self = shift;
+
+	return $self->scans;
+}
+
 1;	
